@@ -111,7 +111,7 @@ dict_equivalencies = {"WFI_BB": u.spectral_density(6483.58 * u.AA),
 # ================== Useful function ====================== #
 
 
-def get_conversion_factor(input_unit, output_unit, filter_name="WFI"):
+def get_conversion_factor(input_unit, output_unit, filter_name="WFI", dict_equiv=dict_equivalencies):
     """ Conversion of units from an input one
     to an output one
      
@@ -121,21 +121,24 @@ def get_conversion_factor(input_unit, output_unit, filter_name="WFI"):
         Input astropy unit to analyse
     output_unit: astropy unit
         Astropy unit to compare to input unit.
-    equivalencies: astropy equivalency
-        Used in case there is an existing equivalency
-        to help the conversion
+    filter_name: str, optional
+        Name of the filter
+    dict_equiv: dict, optional
+        Dictionary listing the equivalencies for various filters.
+        Will be using it if the filter name is the key list
+        to help with the conversion.
     
     Returns
     -------
     conversion: astropy unit conversion
     """
 
-    if filter_name not in dict_equivalencies:
+    if filter_name not in dict_equiv:
         upipe.print_warning("Didn't find conversion for this filter. "
                             "Using 1.0 as a conversion factor")
         return 1.0
 
-    equivalencies = dict_equivalencies[filter_name]
+    equivalencies = dict_equiv[filter_name]
     # First testing if the quantities are Quantity
     # If not, transform them 
     if not isinstance(input_unit, u.quantity.Quantity):
@@ -494,6 +497,18 @@ class AlignMuseDataset(object):
         chunk_size: int [15]
             Size in pixels of the chunk used to bin and compute the 
             normalisation factors
+        pivot_lambda: float, optional
+            Pivot wavelength (in Angstroems) for the reference filter
+        equivalency: astrooy unit equivalency, optional
+            Equivalency for unit conversion of the flux in the reference image.
+            The entry should be of the form: u.spectral_density(6483.58 * u.AA)
+            where u is units of astropy
+            Instead of an equivalency, the user can provide a pivot wavelength via
+            the pivot_lambda keyword.
+            If equivalency is provided, pivot_lambda is ignored.
+            If not provided, as set of predefined equivalencies will be used. When the filter
+            name is not part of the provided list of equivalencies, a conversion factor of 1
+            is used.
 
         Other keywords
         --------------
@@ -549,7 +564,7 @@ class AlignMuseDataset(object):
         self._debug = kwargs.pop("debug", False)
         if self._debug:
             upipe.print_warning("In DEBUG Mode [more printing]")
-        # Backward compatibility - TO BE REMOVED when fixed
+        # Backward compatibility - TO BE REMOVED/dict_equi when fixed
         self._backward_comp = kwargs.pop("backward_comp", True)
 
         # Check if folder reference exists
@@ -600,12 +615,18 @@ class AlignMuseDataset(object):
 
         # Getting the unit conversions
         self.convert_units = kwargs.pop("convert_units", True)
+        # Merging dictionaries if needed
+        pivot_lambda = kwargs.pop("pivot_lambda", 6483.58)
+        equivalency = kwargs.pop("equivalency", u.spectral_density(pivot_lambda * u.AA))
+        self.dict_equiv = copy.copy(dict_equivalencies)
+        self.dict_equiv.update({self.filter_name: equivalency})
         if self.convert_units:
             self.ref_unit = kwargs.pop("ref_unit", default_reference_unit)
             self.muse_unit = kwargs.pop("muse_unit", default_muse_unit)
             self.conversion_factor = get_conversion_factor(self.ref_unit,
                                                            self.muse_unit,
-                                                           self.filter_name)
+                                                           filter_name=self.filter_name,
+                                                           dict_equiv=self.dict_equiv)
         else:
             self.conversion_factor = 1.0
 
@@ -786,21 +807,21 @@ class AlignMuseDataset(object):
             nstate_max = self._nstate
 
         for nstate in range(nstate_max+1):
-            state_name = "state_{nstate:02d}"
+            state_name = f"state_{nstate:02d}"
             if hasattr(self, state_name):
-                print("State = {nstate_02d} exists")
+                print(f"State = {state_name} exists")
             else:
-                print("State = {nstate_02d} does *not* exist")
+                print(f"State = {state_name} does *not* exist")
 
-    def transfer_extra_to_guess(self, transfer_rotation=False):
+    def transfer_extra_to_guess(self, transfer_rotation=True):
         """Transfer the values of the extra offset as a guess
         """
         # First save the existing state
         self.save_state()
 
-        # Copy the values
-        self.init_off_pixel = copy.copy(self.extra_off_pixel)
-        self.init_off_arcsec = copy.copy(self.extra_off_arcsec)
+        # Copy the values from total to init
+        self.init_off_pixel = copy.copy(self._total_off_pixel)
+        self.init_off_arcsec = copy.copy(self._total_off_arcsec)
 
         # Reset the extra offsets
         self.extra_off_pixel = np.zeros_like(self.init_off_pixel)
@@ -808,8 +829,8 @@ class AlignMuseDataset(object):
 
         # Deal with rotation too if needed
         if transfer_rotation:
-            self.init_rotangles = copy.copy(self.extra_rotangles)
-            self.extra_rotangles = np.zeros_like(self.init_off_arcsec)
+            self.init_rotangles = copy.copy(self._total_rotangles)
+            self.extra_rotangles = np.zeros_like(self.init_rotangles)
 
     def init_guess_offset(self, **kwargs):
         """Initialise first guess, either from cross-correlation (default)
@@ -1362,6 +1383,7 @@ class AlignMuseDataset(object):
         squeeze = kwargs.pop("squeeze", True)
         border = kwargs.pop("border", self.border)
         mask_stars = kwargs.pop("mask_stars", False)
+        mirror_nan = kwargs.pop("mirror_nan", True)
         threshold = kwargs.pop("threshold", self.default_threshold)
         if threshold is None:
             threshold = self.default_threshold
@@ -1384,6 +1406,9 @@ class AlignMuseDataset(object):
         ima_muse = flatclean_image(muse_hdu.data, border, self.dynamic_range, self.median_window,
                                    threshold=threshold, squeeze=squeeze, remove_bkg=remove_bkg)
 
+        if mirror_nan:
+            ima_ref[np.isnan(ima_muse)] = np.nan
+
         if mask_stars:
             ima_ref = mask_point_sources(ima_ref)
             ima_muse = mask_point_sources(ima_muse)
@@ -1516,7 +1541,9 @@ class AlignMuseDataset(object):
         save_plot : bool
             Whether to save the optical flow diagnostic plots or not.
         """
-        self.iterate_on_optical_flow_ima(nima, verbose=verbose, use_rotation=use_rotation, **kwargs)
+        reset_opf = kwargs.pop("reset_optical_flow", True)
+        self.iterate_on_optical_flow_ima(nima, verbose=verbose, use_rotation=use_rotation,
+                                         reset_optical_flow=reset_opf, **kwargs)
         self.apply_optical_flow_offset_ima(nima)
         if save_plot:
             plt.ioff()
