@@ -399,7 +399,15 @@ class MuseCubeMosaic(CubeMosaic):
             except:
                 pass
 
-        u_units = np.unique(list_units)
+        try:
+            u_units = np.unique(list_units)
+        except u.UnitConversionError:
+            print_error("Please check that all Cubes have the same unit "
+                        "[e.g., 'from mpdaf.obj import Cube' and then 'print(Cube(name).unit' "
+                        "for all involved cubes")
+            print_error("- Aborting -")
+            return
+
         if len(u_units) == 0:
             print("Warning: no unit found in input cubes, will set dimensionless one")
             self.unit = u.dimensionless_unscaled
@@ -444,8 +452,7 @@ class MuseCubeMosaic(CubeMosaic):
                                                                self.included_suffix,
                                                                self.excluded_suffix,
                                                                name_list="Existing Cubes")
-            print_info("Found {} Cubes after suffix filtering".format(
-                len(list_existing_cubes)))
+            print_info(f"Found {len(list_existing_cubes)} Cubes after suffix filtering")
 
             # Filtering the list using the input pointing table
             if self.pointing_table is not None:
@@ -453,6 +460,7 @@ class MuseCubeMosaic(CubeMosaic):
                                                             pointing_table=self.pointing_table,
                                                             str_dataset=self.str_dataset,
                                                             ndigits=self.ndigits)
+            print_info(f"Found {len(list_cubes)} Cubes after pointing table filtering")
 
             # OLD WAY TO BE REMOVED
             # # Filter the list with the pointing dictionary if given
@@ -466,20 +474,20 @@ class MuseCubeMosaic(CubeMosaic):
 
             # Take (or not) the fixed Cubes
             if self.use_fixed_cubes:
-                print_warning("Using Corrected cubes with prefix {} "
-                              "when relevant".format(self.prefix_fixed_cubes))
+                print_warning(f"Using Corrected cubes with prefix '{self.prefix_fixed_cubes}' "
+                              "when relevant")
                 prefix_to_consider = "{0}{1}".format(self.prefix_fixed_cubes,
                                                      self.prefix_cubes)
                 list_fixed_cubes = glob.glob("{0}{1}*fits".format(self.folder_cubes,
                                                                   prefix_to_consider))
-                print_info("Initial set of {:02d} Corrected "
-                           "cubes found".format(len(list_fixed_cubes)))
+                print_info(f"Initial set of {len(list_fixed_cubes):02d} Corrected "
+                           "cubes found")
 
                 # if the list of exclusion suffix is empty, just use all cubes
                 list_fixed_cubes = filter_list_with_suffix_list(list_fixed_cubes,
-                                                                 self.included_suffix,
-                                                                 self.excluded_suffix,
-                                                                 name_list="Fixed Cubes")
+                                                                self.included_suffix,
+                                                                self.excluded_suffix,
+                                                                name_list="Fixed Cubes")
 
                 # Looping over the existing fixed pixtables
                 for fixed_cube in list_fixed_cubes:
@@ -503,6 +511,7 @@ class MuseCubeMosaic(CubeMosaic):
 
             # if the list of suffix is empty, just use all cubes
             if len(self.list_suffix) > 0:
+                print_info("Filtering with added suffixes")
                 # Filtering out the ones that don't have any of the suffixes
                 temp_list_cubes = []
                 for l in list_cubes:
@@ -513,8 +522,9 @@ class MuseCubeMosaic(CubeMosaic):
         # Attach the other properties to the list of cubes (e.g. PSF)
         self.list_cubes = []
         # Names for the OBs
-        str_dataset = kwargs.pop("str_dataset", default_str_dataset)
-        ndigits = kwargs.pop("ndigits", default_ndigits)
+        str_dataset = kwargs.pop("str_dataset", self.str_dataset)
+        ndigits = kwargs.pop("ndigits", self.ndigits)
+
         for name in list_cubes:
             self.list_cubes.append(BasicFile(name))
             if len(self.dict_psf) > 0:
